/// <reference types="node" />
import { AffineOptions, AvifOptions, BoolEnum, ClaheOptions, Color, ExtendOptions, FlattenOptions, GifOptions, HeifOptions, JpegOptions, Kernel, Matrix2x2, Matrix3x3, NegateOptions, NormaliseOptions, PngOptions, Raw, RawOptions, Region, ResizeOptions, RotateOptions, Sharp, SharpOptions, SharpenOptions, ThresholdOptions, TiffOptions, TrimOptions, WebpOptions, WriteableMetadata, OverlayOptions } from './decl.d';
/**
 * Represents a captured Sharp operation.
 */
export interface Operation {
    /**
     * The name of the method invoked on the
     * Sharp API.
     */
    method: string;
    /**
     * The arguments passed to the method.
     */
    args: any[];
    /**
     * An optional output type descriptor,
     * identifying the output mime-type and
     * extension from the current operation.
     */
    outputType?: {
        mimeType: string;
        extension: string;
    };
}
/**
 * The SharpOperations class is a wrapper around the
 * Sharp API that allows to capture the operations
 * performed on the local Sharp API and to forward
 * them to the remote compute.
 *
 * This allows users of the AWS CDK to express Sharp
 * operations in a similar way to how they would
 * express them locally.
 */
export declare class SharpOperations implements Sharp {
    /**
     * An array of the operations to capture on the local
     * Sharp API and to forward to the remote compute.
     */
    private ops;
    constructor();
    ensureAlpha(alpha?: number | undefined): SharpOperations;
    extractChannel(channel: 0 | 3 | 2 | 1 | 'red' | 'green' | 'blue' | 'alpha'): SharpOperations;
    joinChannel(images: string | Buffer | ArrayLike<string | Buffer>, options?: SharpOptions | undefined): SharpOperations;
    bandbool(boolOp: keyof BoolEnum): SharpOperations;
    tint(rgb: Color): SharpOperations;
    greyscale(greyscale?: boolean | undefined): SharpOperations;
    grayscale(grayscale?: boolean | undefined): SharpOperations;
    pipelineColourspace(colourspace?: string | undefined): SharpOperations;
    pipelineColorspace(colorspace?: string | undefined): SharpOperations;
    toColourspace(colourspace?: string | undefined): SharpOperations;
    toColorspace(colorspace: string): SharpOperations;
    composite(images: OverlayOptions[]): SharpOperations;
    rotate(angle?: number | undefined, options?: RotateOptions | undefined): SharpOperations;
    flip(flip?: boolean | undefined): SharpOperations;
    flop(flop?: boolean | undefined): SharpOperations;
    affine(matrix: [number, number, number, number] | Matrix2x2, options?: AffineOptions | undefined): SharpOperations;
    sharpen(options?: SharpenOptions): SharpOperations;
    median(size?: number | undefined): SharpOperations;
    blur(sigma?: number | boolean | undefined): SharpOperations;
    flatten(flatten?: boolean | FlattenOptions | undefined): SharpOperations;
    unflatten(): SharpOperations;
    gamma(gamma?: number | undefined, gammaOut?: number | undefined): SharpOperations;
    negate(negate?: boolean | NegateOptions | undefined): SharpOperations;
    normalise(normalise?: NormaliseOptions | undefined): SharpOperations;
    normalize(normalize?: NormaliseOptions | undefined): SharpOperations;
    clahe(options: ClaheOptions): SharpOperations;
    convolve(kernel: Kernel): SharpOperations;
    threshold(threshold?: number | undefined, options?: ThresholdOptions | undefined): SharpOperations;
    boolean(operand: string | Buffer, operator: keyof BoolEnum, options?: {
        raw: Raw;
    } | undefined): SharpOperations;
    linear(a?: number | number[] | null | undefined, b?: number | number[] | undefined): SharpOperations;
    recomb(inputMatrix: Matrix3x3): SharpOperations;
    modulate(options?: {
        brightness?: number | undefined;
        saturation?: number | undefined;
        hue?: number | undefined;
        lightness?: number | undefined;
    } | undefined): SharpOperations;
    withMetadata(withMetadata?: WriteableMetadata | undefined): SharpOperations;
    jpeg(options?: JpegOptions | undefined): SharpOperations;
    png(options?: PngOptions | undefined): SharpOperations;
    webp(options?: WebpOptions | undefined): SharpOperations;
    gif(options?: GifOptions | undefined): SharpOperations;
    avif(options?: AvifOptions | undefined): SharpOperations;
    heif(options?: HeifOptions | undefined): SharpOperations;
    tiff(options?: TiffOptions | undefined): SharpOperations;
    raw(options?: RawOptions | undefined): SharpOperations;
    resize(widthOrOptions?: number | ResizeOptions | null, height?: number | null, options?: ResizeOptions): SharpOperations;
    extend(extend: number | ExtendOptions): SharpOperations;
    extract(region: Region): SharpOperations;
    trim(trim?: string | number | TrimOptions | undefined): SharpOperations;
    removeAlpha(): SharpOperations;
    getOps(): Operation[];
}
/**
 * Creates a sharp instance from an image.
 * @returns A sharp instance that can be used to chain operations
 */
export declare function sharp(): SharpOperations;
